#include "..\script_component.hpp"

/*
 * Author: IDSolutions
 * Creates a delivery task module
 *
 * Arguments:
 * None
 *
 * Return Value:
 * None
 *
 * Example:
 * call forge_client_task_fnc_deliveryModule;
 *
 * Public: No
 */

// Module category
private _category = "Forge Tasks";
private _subCategory = "Delivery Tasks";

// Create the module
private _module = createDialog "RscDisplayAttributes";
_module setVariable ["category", _category];
_module setVariable ["subcategory", _subCategory];
_module setVariable ["description", "Configure a delivery task"];

// Add fields for task configuration
[_module, "Task ID", "taskID", "", true] call BIS_fnc_addAttribute;
[_module, "Fail Limit", "limitFail", "1", true] call BIS_fnc_addAttribute;
[_module, "Success Count", "limitSuccess", "3", true] call BIS_fnc_addAttribute;
[_module, "Delivery Zone", "deliveryZone", "", true] call BIS_fnc_addAttribute;
[_module, "Company Funds Reward", "companyFunds", "250000", true] call BIS_fnc_addAttribute;
[_module, "Rating Loss on Fail", "ratingFail", "-75", true] call BIS_fnc_addAttribute;
[_module, "Rating Gain on Success", "ratingSuccess", "300", true] call BIS_fnc_addAttribute;
[_module, "End Mission on Success", "endSuccess", "false", false] call BIS_fnc_addAttribute;
[_module, "End Mission on Fail", "endFail", "false", false] call BIS_fnc_addAttribute;
[_module, "Time Limit (seconds)", "timeLimit", "", false] call BIS_fnc_addAttribute;

// Add confirm button handler
_module setVariable ["onConfirm", {
    params ["_module"];
    
    private _taskID = _module getVariable ["taskID", ""];
    private _limitFail = parseNumber (_module getVariable ["limitFail", "1"]);
    private _limitSuccess = parseNumber (_module getVariable ["limitSuccess", "3"]);
    private _deliveryZone = _module getVariable ["deliveryZone", ""];
    private _companyFunds = parseNumber (_module getVariable ["companyFunds", "250000"]);
    private _ratingFail = parseNumber (_module getVariable ["ratingFail", "-75"]);
    private _ratingSuccess = parseNumber (_module getVariable ["ratingSuccess", "300"]);
    private _endSuccess = _module getVariable ["endSuccess", "false"] == "true";
    private _endFail = _module getVariable ["endFail", "false"] == "true";
    private _timeLimit = _module getVariable ["timeLimit", ""];
    
    // Convert time limit to number or nil
    private _timeLimitNum = if (_timeLimit == "") then { nil } else { parseNumber _timeLimit };
    
    // Create the task
    private _params = [_taskID, _limitFail, _limitSuccess, _deliveryZone, _companyFunds, _ratingFail, _ratingSuccess, _endSuccess, _endFail];
    if (!isNil "_timeLimitNum") then {
        _params pushBack _timeLimitNum;
    };
    
    ["delivery", _params] remoteExec ["forge_client_task_fnc_handler", 2, false];
}];
